@@ -16,7 +16,7 @@ class CombinatorialPromptGenerator(PromptGenerator):
         self._wildcard_manager = wildcard_manager
         self._generator = CombinatorialGenerator(wildcard_manager, ignore_whitespace=ignore_whitespace)
 
-    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> Iterable[str]:
+    def generate(self, template, max_prompts:int|None=constants.MAX_IMAGES) -> Iterable[str]:
         if template is None or len(template) == 0:
             return [""]
         prompts = self._generator.generate_prompts(template, max_prompts)
