@@ -7,8 +7,12 @@ class WildcardFile:
     def __init__(self, path: Path, encoding="utf8"):
         self._path = path
         self._encoding = encoding
+        self._cache = None
 
     def get_wildcards(self) -> set[str]:
+        if self._cache != None:
+            return self._cache
+    
         is_empty_line = (
             lambda line: line is None
             or line.strip() == ""
@@ -17,4 +21,5 @@ class WildcardFile:
 
         with self._path.open(encoding=self._encoding, errors="ignore") as f:
             lines = [line.strip() for line in f if not is_empty_line(line)]
-            return set(lines)
+            self._cache = set(lines)
+            return self._cache
